@@ -1,5 +1,5 @@
 /* PSPP - a program for statistical analysis.
-   Copyright (C) 2007, 2010 Free Software Foundation, Inc.
+   Copyright (C) 2007, 2010, 2016 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 #define SPREADSHEET_READ_H 1
 
 #include <stdbool.h>
+#include <libpspp/compiler.h>
 
 struct casereeader;
 
@@ -59,28 +60,32 @@ enum spreadsheet_type
 
 struct spreadsheet
 {
-  const char *file_name;
+  char *file_name;
 
   enum spreadsheet_type type;
 
   /* The total number of sheets in the "workbook" */
   int n_sheets;
 
-  /* The dictionary */
-  struct dictionary *dict;
+  /* The dictionary for client's reference.
+     Client must clone if it needs a permanent or modifiable copy. */
+  const struct dictionary *dict;
+
+  int ref_cnt;
 };
 
 
 struct casereader * spreadsheet_make_reader (struct spreadsheet *, const struct spreadsheet_read_options *);
 
-const char * spreadsheet_get_sheet_name (struct spreadsheet *s, int n);
-char * spreadsheet_get_sheet_range (struct spreadsheet *s, int n);
+const char * spreadsheet_get_sheet_name (struct spreadsheet *s, int n) OPTIMIZE(2);
+char * spreadsheet_get_sheet_range (struct spreadsheet *s, int n) OPTIMIZE(2);
 
 
 char * create_cell_ref (int col0, int row0);
 char *create_cell_range (int col0, int row0, int coli, int rowi);
 
-void spreadsheet_destroy (struct spreadsheet *);
+void spreadsheet_unref (struct spreadsheet *);
+void spreadsheet_ref (struct spreadsheet *);
 
 
 
