@@ -1,5 +1,5 @@
 /* PSPP - a program for statistical analysis.
-   Copyright (C) 2005 Free Software Foundation, Inc.
+   Copyright (C) 2005, 2009, 2010 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,32 +15,24 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
 #include <config.h>
-#include <libpspp/message.h>
-#include <libpspp/str.h>
-#include <language/lexer/lexer.h>
-#include <language/command.h>
-#include <output/table.h>
-#include <output/manager.h>
 
-#include "xalloc.h"
+#include "language/command.h"
+#include "language/lexer/lexer.h"
+#include "libpspp/message.h"
+#include "libpspp/str.h"
+#include "output/text-item.h"
+
+#include "gl/xalloc.h"
 
 /* Echos a string to the output stream */
 int
 cmd_echo (struct lexer *lexer, struct dataset *ds UNUSED)
 {
-  struct tab_table *tab;
-
-  if (lex_token (lexer) != T_STRING)
+  if (!lex_force_string (lexer))
     return CMD_FAILURE;
 
-  tab = tab_create(1, 1, 0);
-
-  tab_dim (tab, tab_natural_dimensions);
-  tab_flags (tab, SOMF_NO_TITLE );
-
-  tab_text(tab, 0, 0, 0, ds_cstr (lex_tokstr (lexer)));
-
-  tab_submit(tab);
+  text_item_submit (text_item_create (TEXT_ITEM_ECHO, lex_tokcstr (lexer)));
+  lex_get (lexer);
 
   return CMD_SUCCESS;
 }
