@@ -1,5 +1,5 @@
 /* PSPP - a program for statistical analysis.
-   Copyright (C) 2009, 2011, 2014 Free Software Foundation, Inc.
+   Copyright (C) 2009, 2011, 2014, 2015 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
 #include <config.h>
-
+#include "math/chart-geometry.h"
 #include "output/charts/plot-hist.h"
 
 #include <float.h>
@@ -25,6 +25,7 @@
 #include "output/cairo-chart.h"
 
 #include "gl/xvasprintf.h"
+#include "gl/minmax.h"
 
 #include "gettext.h"
 #define _(msgid) gettext (msgid)
@@ -68,29 +69,24 @@ histogram_write_legend (cairo_t *cr, const struct xrchart_geometry *geom,
 
 static void
 hist_draw_bar (cairo_t *cr, const struct xrchart_geometry *geom,
-               const gsl_histogram *h, int bar, bool label)
+               const gsl_histogram *h, int bar)
 {
   double upper;
   double lower;
   double height;
 
-  const size_t bins = gsl_histogram_bins (h);
+  assert ( 0 == gsl_histogram_get_range (h, bar, &lower, &upper));
+  assert ( upper >= lower);
 
   const double x_pos =
-    (geom->axis[SCALE_ABSCISSA].data_max - geom->axis[SCALE_ABSCISSA].data_min) *
-    bar / (double) bins ;
-
-  const double width =
-    (geom->axis[SCALE_ABSCISSA].data_max - geom->axis[SCALE_ABSCISSA].data_min) / (double) bins ;
-
-  assert ( 0 == gsl_histogram_get_range (h, bar, &lower, &upper));
-
-  assert ( upper >= lower);
+    (lower - geom->axis[SCALE_ABSCISSA].min) * geom->axis[SCALE_ABSCISSA].scale
+    +  geom->axis[SCALE_ABSCISSA].data_min;
+  const double width = (upper - lower) * geom->axis[SCALE_ABSCISSA].scale;
 
   height = geom->axis[SCALE_ORDINATE].scale * gsl_histogram_get (h, bar);
 
   cairo_rectangle (cr,
-		   geom->axis[SCALE_ABSCISSA].data_min + x_pos,
+		   x_pos,
 		   geom->axis[SCALE_ORDINATE].data_min,
                    width, height);
   cairo_save (cr);
@@ -101,11 +97,6 @@ hist_draw_bar (cairo_t *cr, const struct xrchart_geometry *geom,
   cairo_fill_preserve (cr);
   cairo_restore (cr);
   cairo_stroke (cr);
-
-  if (label)
-    draw_tick (cr, geom, SCALE_ABSCISSA, bins > 10,
-	       x_pos + width / 2.0, "%.*g",
-               DBL_DIG + 1, (upper + lower) / 2.0);
 }
 
 void
@@ -127,13 +118,17 @@ xrchart_draw_histogram (const struct chart_item *chart_item, cairo_t *cr,
       return;
     }
 
-  bins = gsl_histogram_bins (h->gsl_hist);
+  xrchart_write_yscale (cr, geom, 0, gsl_histogram_max_val (h->gsl_hist));
+  xrchart_write_xscale (cr, geom, gsl_histogram_min (h->gsl_hist),
+			gsl_histogram_max (h->gsl_hist));
 
-  xrchart_write_yscale (cr, geom, 0, gsl_histogram_max_val (h->gsl_hist), 5);
+
+  /* Draw the ticks and compute if the rendered tick text is wider than the bin */
+  bins = gsl_histogram_bins (h->gsl_hist);
 
   for (i = 0; i < bins; i++)
     {
-      hist_draw_bar (cr, geom, h->gsl_hist, i, true);
+      hist_draw_bar (cr, geom, h->gsl_hist, i);
     }
 
   histogram_write_legend (cr, geom, h->n, h->mean, h->stddev);
@@ -142,32 +137,38 @@ xrchart_draw_histogram (const struct chart_item *chart_item, cairo_t *cr,
       && h->n != SYSMIS && h->mean != SYSMIS && h->stddev != SYSMIS)
     {
       /* Draw the normal curve */
-      double d;
-      double x_min, x_max, not_used;
-      double abscissa_scale;
+      double x_min, x_max;
       double ordinate_scale;
-      double range;
+      double binwidth;
+      double x;
 
-      gsl_histogram_get_range (h->gsl_hist, 0, &x_min, &not_used);
-      range = not_used - x_min;
-      gsl_histogram_get_range (h->gsl_hist, bins - 1, &not_used, &x_max);
+      gsl_histogram_get_range (h->gsl_hist, 0, &x_min, &x_max);
+      binwidth = x_max - x_min;
 
-      abscissa_scale = (geom->axis[SCALE_ABSCISSA].data_max - geom->axis[SCALE_ABSCISSA].data_min) / (x_max - x_min);
-      ordinate_scale = (geom->axis[SCALE_ORDINATE].data_max - geom->axis[SCALE_ORDINATE].data_min) /
-	gsl_histogram_max_val (h->gsl_hist);
+      /* The integral over the histogram is binwidth * sum(bin_i), while the integral over the pdf is 1 */
+      /* Therefore the pdf has to be scaled accordingly such that the integrals are equal               */
+      ordinate_scale = binwidth * gsl_histogram_sum(h->gsl_hist);
+
+      /* Clip normal curve to the rectangle formed by the axes. */
+      cairo_save (cr);
+      cairo_rectangle (cr, geom->axis[SCALE_ABSCISSA].data_min, geom->axis[SCALE_ORDINATE].data_min,
+                       geom->axis[SCALE_ABSCISSA].data_max - geom->axis[SCALE_ABSCISSA].data_min,
+                       geom->axis[SCALE_ORDINATE].data_max - geom->axis[SCALE_ORDINATE].data_min);
+      cairo_clip (cr);
 
       cairo_move_to (cr, geom->axis[SCALE_ABSCISSA].data_min, geom->axis[SCALE_ORDINATE].data_min);
-      for (d = geom->axis[SCALE_ABSCISSA].data_min;
-	   d <= geom->axis[SCALE_ABSCISSA].data_max;
-	   d += (geom->axis[SCALE_ABSCISSA].data_max - geom->axis[SCALE_ABSCISSA].data_min) / 100.0)
+      for (x = geom->axis[SCALE_ABSCISSA].min;
+	   x <= geom->axis[SCALE_ABSCISSA].max;
+	   x += (geom->axis[SCALE_ABSCISSA].max - geom->axis[SCALE_ABSCISSA].min) / 100.0)
 	{
-	  const double x = (d - geom->axis[SCALE_ABSCISSA].data_min) / abscissa_scale + x_min;
-	  const double y = h->n * range *
-	    gsl_ran_gaussian_pdf (x - h->mean, h->stddev);
-
-          cairo_line_to (cr, d, geom->axis[SCALE_ORDINATE].data_min  + y * ordinate_scale);
-
+	  const double y = gsl_ran_gaussian_pdf (x - h->mean, h->stddev) * ordinate_scale;
+	  /* Transform to drawing coordinates */
+	  const double x_pos = (x - geom->axis[SCALE_ABSCISSA].min) * geom->axis[SCALE_ABSCISSA].scale + geom->axis[SCALE_ABSCISSA].data_min;
+	  const double y_pos = (y - geom->axis[SCALE_ORDINATE].min) * geom->axis[SCALE_ORDINATE].scale + geom->axis[SCALE_ORDINATE].data_min;
+          cairo_line_to (cr, x_pos, y_pos);
 	}
       cairo_stroke (cr);
+
+      cairo_restore (cr);
     }
 }
