@@ -53,7 +53,7 @@ get_proportion (PsppireDialogActionBinomial *act, double *prop)
     if (endptr == text)
       return FALSE;
 
-    return TRUE; 
+    return TRUE;
 }
 
 static gboolean
@@ -96,19 +96,13 @@ refresh (PsppireDialogAction *da)
 }
 
 
-static void
-psppire_dialog_action_binomial_activate (PsppireDialogAction *a)
+static GtkBuilder *
+psppire_dialog_action_binomial_activate (PsppireDialogAction *a, GVariant *param)
 {
   PsppireDialogActionBinomial *act = PSPPIRE_DIALOG_ACTION_BINOMIAL (a);
   PsppireDialogAction *pda = PSPPIRE_DIALOG_ACTION (a);
 
-  GHashTable *thing = psppire_dialog_action_get_hash_table (pda);
-  GtkBuilder *xml = g_hash_table_lookup (thing, a);
-  if (!xml)
-    {
-      xml = builder_new ("binomial.ui");
-      g_hash_table_insert (thing, a, xml);
-    }
+  GtkBuilder *xml = builder_new ( "binomial.ui");
 
   pda->dialog = get_widget_assert   (xml, "binomial-dialog");
   pda->source = get_widget_assert   (xml, "dict-view");
@@ -126,10 +120,8 @@ psppire_dialog_action_binomial_activate (PsppireDialogAction *a)
   psppire_dialog_action_set_refresh (pda, refresh);
 
   psppire_dialog_action_set_valid_predicate (pda,
-					dialog_state_valid);
-
-  if (PSPPIRE_DIALOG_ACTION_CLASS (psppire_dialog_action_binomial_parent_class)->activate)
-    PSPPIRE_DIALOG_ACTION_CLASS (psppire_dialog_action_binomial_parent_class)->activate (pda);
+					     dialog_state_valid);
+  return xml;
 }
 
 
@@ -170,7 +162,7 @@ generate_syntax (const PsppireDialogAction *a)
 static void
 psppire_dialog_action_binomial_class_init (PsppireDialogActionBinomialClass *class)
 {
-  psppire_dialog_action_set_activation (class, psppire_dialog_action_binomial_activate);
+  PSPPIRE_DIALOG_ACTION_CLASS (class)->initial_activate = psppire_dialog_action_binomial_activate;
 
   PSPPIRE_DIALOG_ACTION_CLASS (class)->generate_syntax = generate_syntax;
 }
