@@ -58,19 +58,13 @@ refresh (PsppireDialogAction *rd_)
   gtk_entry_set_text (GTK_ENTRY (rd->variable), "");
 }
 
-static void
-psppire_dialog_action_histogram_activate (PsppireDialogAction *a)
+static GtkBuilder *
+psppire_dialog_action_histogram_activate (PsppireDialogAction *a, GVariant *param)
 {
   PsppireDialogActionHistogram *act = PSPPIRE_DIALOG_ACTION_HISTOGRAM (a);
   PsppireDialogAction *pda = PSPPIRE_DIALOG_ACTION (a);
 
-  GHashTable *thing = psppire_dialog_action_get_hash_table (pda);
-  GtkBuilder *xml = g_hash_table_lookup (thing, a);
-  if (!xml)
-    {
-      xml = builder_new ("histogram.ui");
-      g_hash_table_insert (thing, a, xml);
-    }
+  GtkBuilder *xml = builder_new ( "histogram.ui");
 
   pda->dialog = get_widget_assert (xml, "histogram-dialog");
   pda->source = get_widget_assert (xml, "dict-view");
@@ -83,8 +77,7 @@ psppire_dialog_action_histogram_activate (PsppireDialogAction *a)
   psppire_dialog_action_set_valid_predicate (pda,
 					dialog_state_valid);
 
-  if (PSPPIRE_DIALOG_ACTION_CLASS (psppire_dialog_action_histogram_parent_class)->activate)
-    PSPPIRE_DIALOG_ACTION_CLASS (psppire_dialog_action_histogram_parent_class)->activate (pda);
+  return xml;
 }
 
 
@@ -117,7 +110,7 @@ generate_syntax (const PsppireDialogAction *a)
 static void
 psppire_dialog_action_histogram_class_init (PsppireDialogActionHistogramClass *class)
 {
-  psppire_dialog_action_set_activation (class, psppire_dialog_action_histogram_activate);
+  PSPPIRE_DIALOG_ACTION_CLASS (class)->initial_activate = psppire_dialog_action_histogram_activate;
 
   PSPPIRE_DIALOG_ACTION_CLASS (class)->generate_syntax = generate_syntax;
 }
