@@ -1,5 +1,5 @@
 /* PSPPIRE - a graphical user interface for PSPP.
-   Copyright (C) 2008-2015 Free Software Foundation.
+   Copyright (C) 2008-2015, 2016 Free Software Foundation.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -160,7 +160,7 @@ create_xr (struct psppire_output_view *view)
   cairo_destroy (cr);
 }
 
-/* Return the horizontal position to place a widget whose 
+/* Return the horizontal position to place a widget whose
    width is CHILD_WIDTH */
 static gint
 get_xpos (const struct psppire_output_view *view, gint child_width)
@@ -250,11 +250,23 @@ rerender (struct psppire_output_view *view)
           gtk_layout_move (view->output, item->drawing_area, xpos, view->y);
         }
 
+      {
+	gint minw;
+	gint minh;
+	/* This code probably doesn't bring us anthing, but Gtk
+	   shows warnings if get_preferred_width/height is not
+	   called before the size_allocate below is called. */
+	gtk_widget_get_preferred_width (item->drawing_area, &minw, NULL);
+	gtk_widget_get_preferred_height (item->drawing_area, &minh, NULL);
+	if (th > minh) th = minh;
+	if (tw > minw) tw = minw;
+      }
       alloc.x = xpos;
       alloc.y = view->y;
       alloc.width = tw;
       alloc.height = th;
-      gtk_widget_size_allocate(item->drawing_area,&alloc);
+
+      gtk_widget_size_allocate (item->drawing_area, &alloc);
 
       if (view->max_width < tw)
         view->max_width = tw;
@@ -589,10 +601,12 @@ on_copy (struct psppire_output_view *view)
 }
 
 static void
-on_selection_change (GtkTreeSelection *sel, GtkAction *copy_action)
+on_selection_change (GtkTreeSelection *sel, GAction *copy_action)
 {
   /* The Copy action is available only if there is something selected */
-  gtk_action_set_sensitive (copy_action, gtk_tree_selection_count_selected_rows (sel) > 0);
+  g_object_set (copy_action,
+		"enabled", gtk_tree_selection_count_selected_rows (sel) > 0,
+		NULL);
 }
 
 static void
@@ -617,14 +631,39 @@ on_size_allocate (GtkWidget    *widget,
     }
 }
 
+static void
+on_realize (GtkWidget *overview, GObject *view)
+{
+  GtkTreeSelection *sel = gtk_tree_view_get_selection (GTK_TREE_VIEW (overview));
+  gtk_tree_selection_set_mode (sel, GTK_SELECTION_MULTIPLE);
+
+  GtkWidget *toplevel = gtk_widget_get_toplevel (GTK_WIDGET (overview));
+
+  GAction *copy_action = g_action_map_lookup_action (G_ACTION_MAP (toplevel),
+						     "copy");
+
+  GAction *select_all_action = g_action_map_lookup_action (G_ACTION_MAP (toplevel),
+							   "select-all");
+
+  g_object_set (copy_action, "enabled", FALSE, NULL);
+
+  g_signal_connect_swapped (select_all_action, "activate",
+			    G_CALLBACK (on_select_all), view);
+
+  g_signal_connect_swapped (copy_action, "activate",
+                            G_CALLBACK (on_copy), view);
+
+  g_signal_connect (sel, "changed", G_CALLBACK (on_selection_change),
+                    copy_action);
+}
+
 struct psppire_output_view *
-psppire_output_view_new (GtkLayout *output, GtkTreeView *overview,
-                         GtkAction *copy_action, GtkAction *select_all_action)
+psppire_output_view_new (GtkLayout *output, GtkTreeView *overview)
 {
   struct psppire_output_view *view;
   GtkTreeViewColumn *column;
   GtkCellRenderer *renderer;
-  GtkTreeSelection *sel;
+
   GtkTreeModel *model;
 
   view = xmalloc (sizeof *view);
@@ -656,6 +695,8 @@ psppire_output_view_new (GtkLayout *output, GtkTreeView *overview,
 
   if (overview)
     {
+      g_signal_connect (overview, "realize", G_CALLBACK (on_realize), view);
+
       model = GTK_TREE_MODEL (gtk_tree_store_new (
                                 N_COLS,
                                 G_TYPE_STRING,  /* COL_NAME */
@@ -664,11 +705,6 @@ psppire_output_view_new (GtkLayout *output, GtkTreeView *overview,
       gtk_tree_view_set_model (overview, model);
       g_object_unref (model);
 
-      sel = gtk_tree_view_get_selection (overview);
-      gtk_tree_selection_set_mode (sel, GTK_SELECTION_MULTIPLE);
-      g_signal_connect (sel, "changed", G_CALLBACK (on_selection_change),
-                        copy_action);
-
       column = gtk_tree_view_column_new ();
       gtk_tree_view_append_column (GTK_TREE_VIEW (overview), column);
       renderer = gtk_cell_renderer_text_new ();
@@ -677,12 +713,6 @@ psppire_output_view_new (GtkLayout *output, GtkTreeView *overview,
 
       g_signal_connect (GTK_TREE_VIEW (overview),
                         "row-activated", G_CALLBACK (on_row_activate), view);
-
-      gtk_action_set_sensitive (copy_action, FALSE);
-      g_signal_connect_swapped (copy_action, "activate",
-                                G_CALLBACK (on_copy), view);
-      g_signal_connect_swapped (select_all_action, "activate",
-                                G_CALLBACK (on_select_all), view);
     }
 
   return view;
@@ -759,17 +789,17 @@ static cairo_t *
 get_cairo_context_from_print_context (GtkPrintContext *context)
 {
   cairo_t *cr = gtk_print_context_get_cairo_context (context);
-  
+
   /*
     For all platforms except windows, gtk_print_context_get_dpi_[xy] returns 72.
     Windows returns 600.
   */
   double xres = gtk_print_context_get_dpi_x (context);
   double yres = gtk_print_context_get_dpi_y (context);
-  
+
   /* This means that the cairo context now has its dimensions in Points */
   cairo_scale (cr, xres / 72.0, yres / 72.0);
-  
+
   return cr;
 }
 
@@ -888,7 +918,7 @@ psppire_output_view_print (struct psppire_output_view *view,
 
   GtkPrintOperation *print = gtk_print_operation_new ();
 
-  if (view->print_settings != NULL) 
+  if (view->print_settings != NULL)
     gtk_print_operation_set_print_settings (print, view->print_settings);
 
   g_signal_connect (print, "begin_print", G_CALLBACK (begin_print), view);
